@@ -22,7 +22,7 @@ if [ "$TASK"x = ""x ] ; then
 			TASK=debian-installer
 			unset COMPLETE
 			;;
-		"2"x)
+		"2"x|"C"x)
 			TASK=debian-installer+kernel
 			unset COMPLETE
 			;;
@@ -40,7 +40,7 @@ if [ -z "$IMAGETARGET" ] ; then
 	IMAGETARGET="official_images"
 fi
 
-for ARCHES in i386 amd64 alpha arm hppa ia64 m68k mips mipsel powerpc s390 sparc source
+for ARCHES in i386 amd64 alpha arm hppa ia64 m68k mips mipsel powerpc s390 sparc kfreebsd-amd64 kfreebsd-i386 source
 do
 	export ARCHES
 	echo "Now we're going to build CD for $ARCHES !"
