@@ -1,15 +1,14 @@
-export TRACE=/org/cdbuilder.debian.org/src/ftp/debian/project/trace/farbror.acc.umu.se
+export TRACE=/org/cdbuilder.debian.org/src/ftp/debian/project/trace/pettersson.debian.org
 export ARCH_DI_DIR=/org/cdbuilder.debian.org/src/deb-cd/d-i
 export HOSTNAME=`hostname -f`
 
 export PUBDIR=/org/cdbuilder.debian.org/dst/deb-cd
 
 export MIRROR=/org/cdbuilder.debian.org/src/ftp/debian
-export BASEDIR=/home/deb-cd/build/debian-cd
-export MKISOFS=/home/deb-cd/build/mkisofs/usr/bin/mkisofs
+export BASEDIR=~/build/debian-cd
+export MKISOFS=~/build/mkisofs/usr/bin/mkisofs
 if [ "$DATE"x = ""x ] ; then
     export DATE=`date -u +%Y%m%d`
 fi
-export PARALLEL=0
 
-export EXTRACTED_SOURCES=/export/ftp/cdimage/cd-sources
+export EXTRACTED_SOURCES=/mnt/nfs-cdimage/cd-sources
