@@ -6,12 +6,16 @@ set -e
 ## See also CONF.sh for the meaning of variables used here.
 
 show_usage() {
-	echo "Usage: $(basename $0) [-d gnome|kde|lxde|xfce|light|all] BC|NETINST|CD|DVD [<ARCH> ...]"
+	echo "Usage: $(basename $0) [OPTIONS] BC|NETINST|CD|DVD [<ARCH> ...]"
+	echo "  Options:"
+	echo "     -d gnome|kde|lxde|xfce|light|all : desktop variant (task) to use"
+	echo "     -V <variant> : extra image variants to enable"
+	echo "     -h : help"
 }
 
 
 # Set configuration file to be used for the build and source it
-export CF=CONF.sh
+export CF=./CONF.sh
 . $CF
 export DEBIAN_CD_CONF_SOURCED=true
 unset UPDATE_LOCAL
@@ -25,20 +29,36 @@ if [ $# -eq 0 ]; then
 fi
 
 desktop=
-if [ "$1" = "-d" ]; then
-	case $2 in
-	    # Note: "gnome" is the special gnome task, not the generic task
-	    gnome|kde|lxde|xfce|light|all)
-		desktop=$2
-		shift 2
+VARIANTS=
+while getopts d:hV: OPT; do
+	case $OPT in
+	    d)
+		case $OPTARG in
+		# Note: "gnome" is the special gnome task, not the generic task
+		    gnome|kde|lxde|xfce|light|all)
+			desktop=$2
+			;;
+		    *)
+			show_usage
+			exit 1
+			;;
+		esac ;;
+	    V)
+		VARIANTS="${VARIANTS:+$VARIANTS }$OPTARG"
 		;;
-	    *)
+	    h)
+		show_usage
+		exit 0
+		;;
+	    \?)
 		show_usage
 		exit 1
 		;;
 	esac
-fi
+done
+shift $(($OPTIND - 1))
 
+export VARIANTS
 export DISKTYPE="$1"
 shift
 
